# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
import sys
from typing import Any, Optional, TYPE_CHECKING, cast

from azure.core.pipeline import policies
from azure.core.rest import HttpRequest, HttpResponse
from azure.core.settings import settings
from azure.mgmt.core import ARMPipelineClient
from azure.mgmt.core.policies import ARMAutoResourceProviderRegistrationPolicy
from azure.mgmt.core.tools import get_arm_endpoints

from ._configuration import MySQLManagementClientConfiguration
from ._utils.serialization import Deserializer, Serializer
from .operations import (
    AdvancedThreatProtectionSettingsOperations,
    AzureADAdministratorsOperations,
    BackupAndExportOperations,
    BackupsOperations,
    CheckNameAvailabilityOperations,
    CheckNameAvailabilityWithoutLocationOperations,
    CheckVirtualNetworkSubnetUsageOperations,
    ConfigurationsOperations,
    DatabasesOperations,
    FabricMirroringSettingsOperations,
    FirewallRulesOperations,
    GetPrivateDnsZoneSuffixOperations,
    LocationBasedCapabilitiesOperations,
    LocationBasedCapabilitySetOperations,
    LogFilesOperations,
    LongRunningBackupOperations,
    LongRunningBackupsOperations,
    MaintenancesOperations,
    OperationProgressOperations,
    OperationResultsOperations,
    Operations,
    PrivateEndpointConnectionsOperations,
    PrivateLinkResourcesOperations,
    ReplicasOperations,
    ServersMigrationOperations,
    ServersOperations,
)

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self  # type: ignore

if TYPE_CHECKING:
    from azure.core import AzureClouds
    from azure.core.credentials import TokenCredential


class MySQLManagementClient:  # pylint: disable=too-many-instance-attributes
    """The Microsoft Azure management API provides create, read, update, and delete functionality for
    Azure MySQL resources including servers, databases, firewall rules, VNET rules, log files and
    configurations with new business model.

    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.mysqlflexibleservers.operations.Operations
    :ivar azure_ad_administrators: AzureADAdministratorsOperations operations
    :vartype azure_ad_administrators:
     azure.mgmt.mysqlflexibleservers.operations.AzureADAdministratorsOperations
    :ivar servers: ServersOperations operations
    :vartype servers: azure.mgmt.mysqlflexibleservers.operations.ServersOperations
    :ivar backup_and_export: BackupAndExportOperations operations
    :vartype backup_and_export:
     azure.mgmt.mysqlflexibleservers.operations.BackupAndExportOperations
    :ivar log_files: LogFilesOperations operations
    :vartype log_files: azure.mgmt.mysqlflexibleservers.operations.LogFilesOperations
    :ivar servers_migration: ServersMigrationOperations operations
    :vartype servers_migration:
     azure.mgmt.mysqlflexibleservers.operations.ServersMigrationOperations
    :ivar backups: BackupsOperations operations
    :vartype backups: azure.mgmt.mysqlflexibleservers.operations.BackupsOperations
    :ivar long_running_backups: LongRunningBackupsOperations operations
    :vartype long_running_backups:
     azure.mgmt.mysqlflexibleservers.operations.LongRunningBackupsOperations
    :ivar long_running_backup: LongRunningBackupOperations operations
    :vartype long_running_backup:
     azure.mgmt.mysqlflexibleservers.operations.LongRunningBackupOperations
    :ivar configurations: ConfigurationsOperations operations
    :vartype configurations: azure.mgmt.mysqlflexibleservers.operations.ConfigurationsOperations
    :ivar databases: DatabasesOperations operations
    :vartype databases: azure.mgmt.mysqlflexibleservers.operations.DatabasesOperations
    :ivar firewall_rules: FirewallRulesOperations operations
    :vartype firewall_rules: azure.mgmt.mysqlflexibleservers.operations.FirewallRulesOperations
    :ivar advanced_threat_protection_settings: AdvancedThreatProtectionSettingsOperations
     operations
    :vartype advanced_threat_protection_settings:
     azure.mgmt.mysqlflexibleservers.operations.AdvancedThreatProtectionSettingsOperations
    :ivar location_based_capability_set: LocationBasedCapabilitySetOperations operations
    :vartype location_based_capability_set:
     azure.mgmt.mysqlflexibleservers.operations.LocationBasedCapabilitySetOperations
    :ivar maintenances: MaintenancesOperations operations
    :vartype maintenances: azure.mgmt.mysqlflexibleservers.operations.MaintenancesOperations
    :ivar private_endpoint_connections: PrivateEndpointConnectionsOperations operations
    :vartype private_endpoint_connections:
     azure.mgmt.mysqlflexibleservers.operations.PrivateEndpointConnectionsOperations
    :ivar private_link_resources: PrivateLinkResourcesOperations operations
    :vartype private_link_resources:
     azure.mgmt.mysqlflexibleservers.operations.PrivateLinkResourcesOperations
    :ivar location_based_capabilities: LocationBasedCapabilitiesOperations operations
    :vartype location_based_capabilities:
     azure.mgmt.mysqlflexibleservers.operations.LocationBasedCapabilitiesOperations
    :ivar check_virtual_network_subnet_usage: CheckVirtualNetworkSubnetUsageOperations operations
    :vartype check_virtual_network_subnet_usage:
     azure.mgmt.mysqlflexibleservers.operations.CheckVirtualNetworkSubnetUsageOperations
    :ivar check_name_availability: CheckNameAvailabilityOperations operations
    :vartype check_name_availability:
     azure.mgmt.mysqlflexibleservers.operations.CheckNameAvailabilityOperations
    :ivar check_name_availability_without_location: CheckNameAvailabilityWithoutLocationOperations
     operations
    :vartype check_name_availability_without_location:
     azure.mgmt.mysqlflexibleservers.operations.CheckNameAvailabilityWithoutLocationOperations
    :ivar operation_results: OperationResultsOperations operations
    :vartype operation_results:
     azure.mgmt.mysqlflexibleservers.operations.OperationResultsOperations
    :ivar operation_progress: OperationProgressOperations operations
    :vartype operation_progress:
     azure.mgmt.mysqlflexibleservers.operations.OperationProgressOperations
    :ivar get_private_dns_zone_suffix: GetPrivateDnsZoneSuffixOperations operations
    :vartype get_private_dns_zone_suffix:
     azure.mgmt.mysqlflexibleservers.operations.GetPrivateDnsZoneSuffixOperations
    :ivar replicas: ReplicasOperations operations
    :vartype replicas: azure.mgmt.mysqlflexibleservers.operations.ReplicasOperations
    :ivar fabric_mirroring_settings: FabricMirroringSettingsOperations operations
    :vartype fabric_mirroring_settings:
     azure.mgmt.mysqlflexibleservers.operations.FabricMirroringSettingsOperations
    :param credential: Credential used to authenticate requests to the service. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service host. Default value is None.
    :type base_url: str
    :keyword cloud_setting: The cloud setting for which to get the ARM endpoint. Default value is
     None.
    :paramtype cloud_setting: ~azure.core.AzureClouds
    :keyword api_version: The API version to use for this operation. Known values are
     "2025-12-01-preview" and None. Default value is None. If not set, the operation's default API
     version will be used. Note that overriding this default value may result in unsupported
     behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: Optional[str] = None,
        *,
        cloud_setting: Optional["AzureClouds"] = None,
        **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        _cloud = cloud_setting or settings.current.azure_cloud  # type: ignore
        _endpoints = get_arm_endpoints(_cloud)
        if not base_url:
            base_url = _endpoints["resource_manager"]
        credential_scopes = kwargs.pop("credential_scopes", _endpoints["credential_scopes"])
        self._config = MySQLManagementClientConfiguration(
            credential=credential,
            subscription_id=subscription_id,
            base_url=cast(str, base_url),
            cloud_setting=cloud_setting,
            credential_scopes=credential_scopes,
            **kwargs
        )

        _policies = kwargs.pop("policies", None)
        if _policies is None:
            _policies = [
                policies.RequestIdPolicy(**kwargs),
                self._config.headers_policy,
                self._config.user_agent_policy,
                self._config.proxy_policy,
                policies.ContentDecodePolicy(**kwargs),
                ARMAutoResourceProviderRegistrationPolicy(),
                self._config.redirect_policy,
                self._config.retry_policy,
                self._config.authentication_policy,
                self._config.custom_hook_policy,
                self._config.logging_policy,
                policies.DistributedTracingPolicy(**kwargs),
                policies.SensitiveHeaderCleanupPolicy(**kwargs) if self._config.redirect_policy else None,
                self._config.http_logging_policy,
            ]
        self._client: ARMPipelineClient = ARMPipelineClient(base_url=cast(str, _endpoint), policies=_policies, **kwargs)

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.azure_ad_administrators = AzureADAdministratorsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.servers = ServersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.backup_and_export = BackupAndExportOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.log_files = LogFilesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.servers_migration = ServersMigrationOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.backups = BackupsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.long_running_backups = LongRunningBackupsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.long_running_backup = LongRunningBackupOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.configurations = ConfigurationsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.databases = DatabasesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.firewall_rules = FirewallRulesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.advanced_threat_protection_settings = AdvancedThreatProtectionSettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.location_based_capability_set = LocationBasedCapabilitySetOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.maintenances = MaintenancesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.private_endpoint_connections = PrivateEndpointConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_link_resources = PrivateLinkResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.location_based_capabilities = LocationBasedCapabilitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.check_virtual_network_subnet_usage = CheckVirtualNetworkSubnetUsageOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.check_name_availability = CheckNameAvailabilityOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.check_name_availability_without_location = CheckNameAvailabilityWithoutLocationOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.operation_results = OperationResultsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.operation_progress = OperationProgressOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.get_private_dns_zone_suffix = GetPrivateDnsZoneSuffixOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.replicas = ReplicasOperations(self._client, self._config, self._serialize, self._deserialize)
        self.fabric_mirroring_settings = FabricMirroringSettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )

    def send_request(self, request: HttpRequest, *, stream: bool = False, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client.send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.base_url", self._config.base_url, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, stream=stream, **kwargs)  # type: ignore

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> Self:
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details: Any) -> None:
        self._client.__exit__(*exc_details)
