# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import AzureADAdministratorsOperations  # type: ignore
from ._operations import ServersOperations  # type: ignore
from ._operations import BackupAndExportOperations  # type: ignore
from ._operations import LogFilesOperations  # type: ignore
from ._operations import ServersMigrationOperations  # type: ignore
from ._operations import BackupsOperations  # type: ignore
from ._operations import LongRunningBackupsOperations  # type: ignore
from ._operations import LongRunningBackupOperations  # type: ignore
from ._operations import ConfigurationsOperations  # type: ignore
from ._operations import DatabasesOperations  # type: ignore
from ._operations import FirewallRulesOperations  # type: ignore
from ._operations import AdvancedThreatProtectionSettingsOperations  # type: ignore
from ._operations import LocationBasedCapabilitySetOperations  # type: ignore
from ._operations import MaintenancesOperations  # type: ignore
from ._operations import PrivateEndpointConnectionsOperations  # type: ignore
from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import LocationBasedCapabilitiesOperations  # type: ignore
from ._operations import CheckVirtualNetworkSubnetUsageOperations  # type: ignore
from ._operations import CheckNameAvailabilityOperations  # type: ignore
from ._operations import CheckNameAvailabilityWithoutLocationOperations  # type: ignore
from ._operations import OperationResultsOperations  # type: ignore
from ._operations import OperationProgressOperations  # type: ignore
from ._operations import GetPrivateDnsZoneSuffixOperations  # type: ignore
from ._operations import ReplicasOperations  # type: ignore
from ._operations import FabricMirroringSettingsOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "AzureADAdministratorsOperations",
    "ServersOperations",
    "BackupAndExportOperations",
    "LogFilesOperations",
    "ServersMigrationOperations",
    "BackupsOperations",
    "LongRunningBackupsOperations",
    "LongRunningBackupOperations",
    "ConfigurationsOperations",
    "DatabasesOperations",
    "FirewallRulesOperations",
    "AdvancedThreatProtectionSettingsOperations",
    "LocationBasedCapabilitySetOperations",
    "MaintenancesOperations",
    "PrivateEndpointConnectionsOperations",
    "PrivateLinkResourcesOperations",
    "LocationBasedCapabilitiesOperations",
    "CheckVirtualNetworkSubnetUsageOperations",
    "CheckNameAvailabilityOperations",
    "CheckNameAvailabilityWithoutLocationOperations",
    "OperationResultsOperations",
    "OperationProgressOperations",
    "GetPrivateDnsZoneSuffixOperations",
    "ReplicasOperations",
    "FabricMirroringSettingsOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
