# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AdministratorProperties,
    AdvancedThreatProtection,
    AdvancedThreatProtectionForUpdate,
    AdvancedThreatProtectionProperties,
    AdvancedThreatProtectionUpdateProperties,
    AzureADAdministrator,
    Backup,
    BackupAndExportRequest,
    BackupAndExportResponse,
    BackupAndExportResponseProperties,
    BackupAndExportResponseType,
    BackupRequestBase,
    BackupSettings,
    BackupStoreDetails,
    Capability,
    CapabilityProperties,
    CapabilityPropertiesV2,
    Configuration,
    ConfigurationForBatchUpdate,
    ConfigurationForBatchUpdateProperties,
    ConfigurationListForBatchUpdate,
    ConfigurationListResult,
    ConfigurationProperties,
    DataEncryption,
    Database,
    DatabaseProperties,
    DelegatedSubnetUsage,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorResponse,
    FabricMirroringSetting,
    FabricMirroringSettingListResult,
    FabricMirroringSettingsProperties,
    FeatureProperty,
    FirewallRule,
    FirewallRuleProperties,
    FullBackupStoreDetails,
    GetPrivateDnsZoneSuffixResponse,
    HighAvailability,
    HighAvailabilityValidationEstimation,
    ImportFromStorageResponseType,
    ImportSourceProperties,
    LogFile,
    LogFileProperties,
    Maintenance,
    MaintenancePolicy,
    MaintenanceProperties,
    MaintenancePropertiesForUpdate,
    MaintenanceUpdate,
    MaintenanceWindow,
    MySQLServerIdentity,
    MySQLServerSku,
    NameAvailability,
    NameAvailabilityRequest,
    Network,
    Operation,
    OperationDisplay,
    OperationProgressResponseType,
    OperationProgressResult,
    OperationStatusExtendedResult,
    OperationStatusResult,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionListResult,
    PrivateEndpointConnectionProperties,
    PrivateLinkResource,
    PrivateLinkResourceProperties,
    PrivateLinkServiceConnectionState,
    ProxyResource,
    Resource,
    Server,
    ServerBackup,
    ServerBackupProperties,
    ServerBackupPropertiesV2,
    ServerBackupV2,
    ServerDetachVNetParameter,
    ServerEditionCapability,
    ServerEditionCapabilityV2,
    ServerForUpdate,
    ServerGtidSetParameter,
    ServerProperties,
    ServerPropertiesForUpdate,
    ServerRestartParameter,
    ServerVersionCapability,
    ServerVersionCapabilityV2,
    SkuCapability,
    SkuCapabilityV2,
    Storage,
    StorageEditionCapability,
    SystemData,
    TrackedResource,
    UserAssignedIdentity,
    ValidateBackupResponse,
    ValidateBackupResponseProperties,
    VirtualNetworkSubnetUsageParameter,
    VirtualNetworkSubnetUsageResult,
)

from ._enums import (  # type: ignore
    AdministratorName,
    AdministratorType,
    AdvancedThreatProtectionName,
    AdvancedThreatProtectionProvisioningState,
    AdvancedThreatProtectionState,
    BackupFormat,
    BackupType,
    BatchOfMaintenance,
    ConfigurationSource,
    CreateMode,
    CreatedByType,
    DataEncryptionType,
    EnableStatusEnum,
    FabricMirroringProvisioningState,
    FabricMirroringSettingsName,
    FabricMirroringState,
    HighAvailabilityMode,
    HighAvailabilityState,
    ImportSourceStorageType,
    IsConfigPendingRestart,
    IsDynamicConfig,
    IsReadOnly,
    MaintenanceProvisioningState,
    MaintenanceState,
    MaintenanceType,
    ManagedServiceIdentityType,
    ObjectType,
    OperationStatus,
    Origin,
    PatchStrategy,
    PrivateEndpointConnectionProvisioningState,
    PrivateEndpointServiceConnectionStatus,
    ProvisioningState,
    ReplicationMode,
    ReplicationRole,
    ResetAllToDefault,
    ServerSkuTier,
    ServerState,
    ServerVersion,
    StorageRedundancyEnum,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AdministratorProperties",
    "AdvancedThreatProtection",
    "AdvancedThreatProtectionForUpdate",
    "AdvancedThreatProtectionProperties",
    "AdvancedThreatProtectionUpdateProperties",
    "AzureADAdministrator",
    "Backup",
    "BackupAndExportRequest",
    "BackupAndExportResponse",
    "BackupAndExportResponseProperties",
    "BackupAndExportResponseType",
    "BackupRequestBase",
    "BackupSettings",
    "BackupStoreDetails",
    "Capability",
    "CapabilityProperties",
    "CapabilityPropertiesV2",
    "Configuration",
    "ConfigurationForBatchUpdate",
    "ConfigurationForBatchUpdateProperties",
    "ConfigurationListForBatchUpdate",
    "ConfigurationListResult",
    "ConfigurationProperties",
    "DataEncryption",
    "Database",
    "DatabaseProperties",
    "DelegatedSubnetUsage",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "FabricMirroringSetting",
    "FabricMirroringSettingListResult",
    "FabricMirroringSettingsProperties",
    "FeatureProperty",
    "FirewallRule",
    "FirewallRuleProperties",
    "FullBackupStoreDetails",
    "GetPrivateDnsZoneSuffixResponse",
    "HighAvailability",
    "HighAvailabilityValidationEstimation",
    "ImportFromStorageResponseType",
    "ImportSourceProperties",
    "LogFile",
    "LogFileProperties",
    "Maintenance",
    "MaintenancePolicy",
    "MaintenanceProperties",
    "MaintenancePropertiesForUpdate",
    "MaintenanceUpdate",
    "MaintenanceWindow",
    "MySQLServerIdentity",
    "MySQLServerSku",
    "NameAvailability",
    "NameAvailabilityRequest",
    "Network",
    "Operation",
    "OperationDisplay",
    "OperationProgressResponseType",
    "OperationProgressResult",
    "OperationStatusExtendedResult",
    "OperationStatusResult",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionListResult",
    "PrivateEndpointConnectionProperties",
    "PrivateLinkResource",
    "PrivateLinkResourceProperties",
    "PrivateLinkServiceConnectionState",
    "ProxyResource",
    "Resource",
    "Server",
    "ServerBackup",
    "ServerBackupProperties",
    "ServerBackupPropertiesV2",
    "ServerBackupV2",
    "ServerDetachVNetParameter",
    "ServerEditionCapability",
    "ServerEditionCapabilityV2",
    "ServerForUpdate",
    "ServerGtidSetParameter",
    "ServerProperties",
    "ServerPropertiesForUpdate",
    "ServerRestartParameter",
    "ServerVersionCapability",
    "ServerVersionCapabilityV2",
    "SkuCapability",
    "SkuCapabilityV2",
    "Storage",
    "StorageEditionCapability",
    "SystemData",
    "TrackedResource",
    "UserAssignedIdentity",
    "ValidateBackupResponse",
    "ValidateBackupResponseProperties",
    "VirtualNetworkSubnetUsageParameter",
    "VirtualNetworkSubnetUsageResult",
    "AdministratorName",
    "AdministratorType",
    "AdvancedThreatProtectionName",
    "AdvancedThreatProtectionProvisioningState",
    "AdvancedThreatProtectionState",
    "BackupFormat",
    "BackupType",
    "BatchOfMaintenance",
    "ConfigurationSource",
    "CreateMode",
    "CreatedByType",
    "DataEncryptionType",
    "EnableStatusEnum",
    "FabricMirroringProvisioningState",
    "FabricMirroringSettingsName",
    "FabricMirroringState",
    "HighAvailabilityMode",
    "HighAvailabilityState",
    "ImportSourceStorageType",
    "IsConfigPendingRestart",
    "IsDynamicConfig",
    "IsReadOnly",
    "MaintenanceProvisioningState",
    "MaintenanceState",
    "MaintenanceType",
    "ManagedServiceIdentityType",
    "ObjectType",
    "OperationStatus",
    "Origin",
    "PatchStrategy",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "ProvisioningState",
    "ReplicationMode",
    "ReplicationRole",
    "ResetAllToDefault",
    "ServerSkuTier",
    "ServerState",
    "ServerVersion",
    "StorageRedundancyEnum",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
